==> robomotion_app-0.8.5.tar.gz: lib/models/get_instance.dart <==
class GetInstanceResponse {
  final bool ok;
  final GetInstanceData? data;
  final String? error;
  GetInstanceResponse({required this.ok, this.data, this.error});

  factory GetInstanceResponse.fromJson(Map<String, dynamic> json) =>
      GetInstanceResponse(
        ok: json['ok'],
        data: json['ok'] && json['data'] != null
            ? GetInstanceData.fromJson(json['data'])
            : null,
        error: json['ok'] ? null : json['error'],
      );

  Map<String, dynamic> toJson() => {
        'ok': ok,
        'data': data?.toJson(),
        'error': error,
      };
}

class GetInstanceData {
  final DateTime? createdAt;
  final DateTime? updatedAt;
  final bool? isDeleted;
  final String? deletedAt;
  final String? id;
  final String? appId;
  final String? workspaceId;
  final String? robotId;
  final String? name;
  final String? description;
  final bool? isRunning;
  final bool? isPublic;
  final int? execTime;
  final DateTime? startedAt;
  final DateTime? finishedAt;
  final String? botId;
  final String? botName;
  final String? flowId;
  final String? versionId;

  GetInstanceData({
    this.createdAt,
    this.updatedAt,
    this.isDeleted,
    this.deletedAt,
    this.id,
    this.appId,
    this.workspaceId,
    this.robotId,
    this.name,
    this.description,
    this.isRunning,
    this.isPublic,
    this.execTime,
    this.startedAt,
    this.finishedAt,
    this.botId,
    this.botName,
    this.flowId,
    this.versionId,
  });

  factory GetInstanceData.fromJson(Map<String, dynamic> json) =>
      GetInstanceData(
        createdAt: json['created_at'] != null
            ? DateTime.parse(json['created_at'])
            : null,
        updatedAt: json['updated_at'] != null
            ? DateTime.parse(json['updated_at'])
            : null,
        isDeleted: json['is_deleted'],
        deletedAt: json['deleted_at'],
        id: json['id'],
        appId: json['app_id'],
        workspaceId: json['workspace_id'],
        robotId: json['robot_id'],
        name: json['name'],
        description: json['description'],
        isRunning: json['is_running'],
        isPublic: json['is_public'],
        execTime: json['exec_time'],
        startedAt: json['started_at'] != null
            ? DateTime.parse(json['started_at'])
            : null,
        finishedAt: json['finished_at'] != null
            ? DateTime.parse(json['finished_at'])
            : null,
        botId: json['bot_id'],
        botName: json['bot_name'],
        flowId: json['flow_id'],
        versionId: json['version_id'],
      );

  Map<String, dynamic> toJson() => {
        'created_at': createdAt?.toIso8601String(),
        'updated_at': updatedAt?.toIso8601String(),
        'is_deleted': isDeleted,
        'deleted_at': deletedAt,
        'id': id,
        'app_id': appId,
        'workspace_id': workspaceId,
        'robot_id': robotId,
        'name': name,
        'description': description,
        'is_running': isRunning,
        'is_public': isPublic,
        'exec_time': execTime,
        'started_at': startedAt?.toIso8601String(),
        'finished_at': finishedAt?.toIso8601String(),
        'bot_id': botId,
        'bot_name': botName,
        'flow_id': flowId,
        'version_id': versionId,
      };
}

==> robomotion_app-0.8.9.tar.gz: lib/models/get_instance.dart <==
class GetInstanceResponse {
  final bool ok;
  final GetInstanceData? data;
  final String? error;
  GetInstanceResponse({required this.ok, this.data, this.error});

  factory GetInstanceResponse.fromJson(Map<dynamic, dynamic> json) =>
      GetInstanceResponse(
        ok: json['ok'],
        data: json['ok'] && json['data'] != null
            ? GetInstanceData.fromJson(json['data'])
            : null,
        error: json['ok'] ? null : json['error'],
      );

  Map<String, dynamic> toJson() => {
        'ok': ok,
        'data': data?.toJson(),
        'error': error,
      };
}

class GetInstanceData {
  final DateTime? createdAt;
  final DateTime? updatedAt;
  final bool? isDeleted;
  final String? deletedAt;
  final String? id;
  final String? appId;
  final String? workspaceId;
  final String? robotId;
  final String? name;
  final String? description;
  final bool? isRunning;
  final bool? isPublic;
  final int? execTime;
  final DateTime? startedAt;
  final DateTime? finishedAt;
  final String? botId;
  final String? botName;
  final String? flowId;
  final String? versionId;

  GetInstanceData({
    this.createdAt,
    this.updatedAt,
    this.isDeleted,
    this.deletedAt,
    this.id,
    this.appId,
    this.workspaceId,
    this.robotId,
    this.name,
    this.description,
    this.isRunning,
    this.isPublic,
    this.execTime,
    this.startedAt,
    this.finishedAt,
    this.botId,
    this.botName,
    this.flowId,
    this.versionId,
  });

  factory GetInstanceData.fromJson(Map<String, dynamic> json) =>
      GetInstanceData(
        createdAt: json['created_at'] != null
            ? DateTime.parse(json['created_at'])
            : null,
        updatedAt: json['updated_at'] != null
            ? DateTime.parse(json['updated_at'])
            : null,
        isDeleted: json['is_deleted'],
        deletedAt: json['deleted_at'],
        id: json['id'],
        appId: json['app_id'],
        workspaceId: json['workspace_id'],
        robotId: json['robot_id'],
        name: json['name'],
        description: json['description'],
        isRunning: json['is_running'],
        isPublic: json['is_public'],
        execTime: json['exec_time'],
        startedAt: json['started_at'] != null
            ? DateTime.parse(json['started_at'])
            : null,
        finishedAt: json['finished_at'] != null
            ? DateTime.parse(json['finished_at'])
            : null,
        botId: json['bot_id'],
        botName: json['bot_name'],
        flowId: json['flow_id'],
        versionId: json['version_id'],
      );

  Map<String, dynamic> toJson() => {
        'created_at': createdAt?.toIso8601String(),
        'updated_at': updatedAt?.toIso8601String(),
        'is_deleted': isDeleted,
        'deleted_at': deletedAt,
        'id': id,
        'app_id': appId,
        'workspace_id': workspaceId,
        'robot_id': robotId,
        'name': name,
        'description': description,
        'is_running': isRunning,
        'is_public': isPublic,
        'exec_time': execTime,
        'started_at': startedAt?.toIso8601String(),
        'finished_at': finishedAt?.toIso8601String(),
        'bot_id': botId,
        'bot_name': botName,
        'flow_id': flowId,
        'version_id': versionId,
      };
}
